==> one_target_mobile_sdk-0.0.5.tar.gz: ios/Classes/SwiftOneTargetMobileSdkPlugin.swift <==
import Flutter
import UIKit
//import SwiftDate
import OneTargetMobileSDK

//format codes: cmd + A then ctrl + I
public class SwiftOneTargetMobileSdkPlugin: NSObject, FlutterPlugin {
    
    var analytics: OneTargetAnalytics? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: Const.sdk, binaryMessenger: registrar.messenger())
        let instance = SwiftOneTargetMobileSdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case Const.getPlatformVersion:
            result("iOS " + UIDevice.current.systemVersion)
        case Const.setupTracking:
            setupTracking(call, result)
        case Const.trackEvent:
            trackEvent(call, result)
        default:
            result(nil)
        }
    }
    
    private func setupTracking(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        let writeKey = arguments["writeKey"] as! String
        print("writeKey " + writeKey)
        let configuration = Configuration(writeKey: writeKey)
        analytics = OneTargetAnalytics.init(configuration: configuration)
        let debugLogsEnabled = arguments["isShowLog"] as! Bool
        print("debugLogsEnabled " + debugLogsEnabled.toString())
        OneTargetAnalytics.debugLogsEnabled = debugLogsEnabled
        result(true)
    }
    
    private func trackEvent(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        let workSpaceId = arguments["workSpaceId"] as! String
        print("workSpaceId " + workSpaceId)
        let identityId = arguments["identityId"] as! Dictionary<String, Any>
        print("identityId: \(identityId as AnyObject)")
        let eventName = arguments["eventName"] as! String
        print("eventName " + eventName)
        let eventDate = arguments["eventDate"] as! NSNumber
        print("eventDateString " + eventDate.stringValue)
        
        //        let date = Date(timeIntervalSince1970: TimeInterval(eventDate.doubleValue))
        //        print("date " + date.toString())
        //
        //        let date = Date() // current time
        
        let date = convertMilliToDate(milliseconds: eventDate.int64Value)
        print("date " + date.toString())
        
        let eventData = arguments["eventData"] as! Dictionary<String, Any>
        print("eventData: \(eventData as AnyObject)")
        
        let outputPlugin = OutputPlugin()
        outputPlugin.result = result
        analytics?.add(plugin: outputPlugin)
        
        analytics?.trackEvent(
            workSpaceId: workSpaceId,
            identityId: identityId,
            eventName: eventName,
            eventDate: date,
            eventData: eventData
        )
        
    }
    
    private func convertMilliToDate(milliseconds: Int64) -> Date {
        return Date(timeIntervalSince1970: (TimeInterval(milliseconds) / 1000))
    }
}

class OutputPlugin: Plugin {
    var analytics: OneTargetAnalytics?
    var type: PluginType = .after
    var result:FlutterResult?
    
    func execute<T>(event: T?) -> T? where T : RawEvent {
        
        let string = event?.prettyPrint() ?? ("")
        print("execute string " + string)
        
        self.result?([
            "response" : string
        ])
        
        return event
    }
}

==> one_target_mobile_sdk-0.0.18.tar.gz: ios/Classes/SwiftOneTargetMobileSdkPlugin.swift <==
import Flutter
import UIKit
//import SwiftDate
import OneTargetMobileSDK

//format codes: cmd + A then ctrl + I
public class SwiftOneTargetMobileSdkPlugin: NSObject, FlutterPlugin {
    let ENV_DEV = 1
    let ENV_STG = 2
    let ENV_PROD = 3
    
    var analytics: OneTargetAnalytics? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: Const.sdk, binaryMessenger: registrar.messenger())
        let instance = SwiftOneTargetMobileSdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case Const.getPlatformVersion:
            result("iOS " + UIDevice.current.systemVersion)
        case Const.setupTracking:
            setupTracking(call, result)
        case Const.trackEvent:
            trackEvent(call, result)
        default:
            result(nil)
        }
    }
    
    private func setupTracking(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        let writeKey = arguments["writeKey"] as! String
        print("writeKey " + writeKey)
        
        let env = arguments["env"] as! Int
        print("env " + env.toString())
        var flavor = "prod"; // default prod
        if(env == ENV_DEV){
            flavor = "dev"
        }else if(env == ENV_STG){
            flavor = "stg"
        }else if(env == ENV_PROD){
            flavor = "prod"
        }
        print("flavor " + flavor)
        
        let configuration = Configuration(writeKey: writeKey, flavor: flavor)
        analytics = OneTargetAnalytics.init(configuration: configuration)
        let debugLogsEnabled = arguments["isShowLog"] as! Bool
        print("debugLogsEnabled " + debugLogsEnabled.toString())
        OneTargetAnalytics.debugLogsEnabled = debugLogsEnabled
        result(true)
    }
    
    //flavor: dev, stg
    private func trackEvent(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        let workSpaceId = arguments["workSpaceId"] as! String
        print("workSpaceId " + workSpaceId)
        let identityId = arguments["identityId"] as! Dictionary<String, Any>
        print("identityId: \(identityId as AnyObject)")
        let profile = arguments["profile"] as! [Dictionary<String, Any>]
        print("profile: \(profile as AnyObject)")
        let eventName = arguments["eventName"] as! String
        print("eventName " + eventName)
        let eventDate = arguments["eventDate"] as! NSNumber
        print("eventDateString " + eventDate.stringValue)
        
        //        let date = Date(timeIntervalSince1970: TimeInterval(eventDate.doubleValue))
        //        print("date " + date.toString())
        //
        //        let date = Date() // current time
        
        let date = convertMilliToDate(milliseconds: eventDate.int64Value)
        print("date " + date.toString())
        let eventData = arguments["eventData"] as! Dictionary<String, Any>
        print("eventData: \(eventData as AnyObject)")
        
        let outputPlugin = OutputPlugin()
        outputPlugin.result = result
        analytics?.add(plugin: outputPlugin)
        
        analytics?.trackEvent(
            workSpaceId: workSpaceId,
            identityId: identityId,
            eventName: eventName,
            eventDate: date,
            eventData: eventData,
            profile: profile
        )
        
    }
    
    private func convertMilliToDate(milliseconds: Int64) -> Date {
        return Date(timeIntervalSince1970: (TimeInterval(milliseconds) / 1000))
    }
}

class OutputPlugin: Plugin {
    var analytics: OneTargetAnalytics?
    var type: PluginType = .after
    var result:FlutterResult?
    
    func execute<T>(event: T?) -> T? where T : RawEvent {
        
        let string = event?.prettyPrint() ?? ("")
        print("execute string " + string)
        
        self.result?([
            "response" : string
        ])
        
        return event
    }
}
